@@ -1,7 +1,4 @@
 #include <Rcpp.h>
-using namespace Rcpp;
-
-// [[Rcpp::plugins(cpp11)]]
 
 #include "json.h"
 using json = nlohmann::json;
@@ -34,7 +31,7 @@ using json = nlohmann::json;
 
 // [[Rcpp::export]]
 std::string circle3() {
-  List v;
+  Rcpp::List v;
   v.push_back("a");
   v.push_back("b");
   v.push_back("c");
